@@ -31,6 +31,8 @@ def sqlacodegen(url, table=None, file=None):
             if field_type:
                 field_module = field_type.__class__.__module__
                 field_class_name = field_type.__class__.__name__
+                if field_class_name == 'INTEGER' and isinstance(column.get("default"), str):
+                    column["default"] = eval(column.get("default"))
                 if field_module not in packages:
                     packages[field_module] = []
                 if field_class_name not in packages[field_module]:
@@ -42,6 +44,7 @@ def sqlacodegen(url, table=None, file=None):
                    "from sqlalchemy import Column\n"
     for p, c in packages.items():
         file_content += f'from {p} import {",".join(c)}\n'
+    file_content += "\nBase = declarative_base()\n"
     for t in tables:
         file_content += t.get("class_model")
     if file:
